from sadie.models.base import AbstractModel

class SimpleModel(AbstractModel):
    pass
